@@ -1,3 +1,8 @@
+from __future__ import absolute_import
+
+import codecs
+import six
+
 from .base_description import BaseDescription
 
 __author__ = "Jon Reid"
@@ -23,11 +28,17 @@ class StringDescription(BaseDescription):
     """
 
     def __init__(self):
-        self.out = ""
+        self.out = ''
 
     def __str__(self):
         """Returns the description."""
         return self.out
 
     def append(self, string):
-        self.out += str(string)
+        if six.PY3:
+            self.out += str(string)
+        else:
+            if isinstance(string, unicode):
+                self.out += string
+            else:
+                self.out += unicode(string, errors="ignore")
